// Stefanie Miller
// CPS 406
// November 4, 1999

// ui.java
//
//    A user interface applet that graphs functions on a canvas.


import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class ui extends Applet implements ActionListener 
{
    //=========================================================================
    // Private Instance variables
    //=========================================================================
    protected int    selectedFunction; // the index of the selected function
    protected int    zoomFactor = 2;   // the factor to zoom in/out
    protected Graph  ga;               // the graphing canvas
    protected Choice pulldownList;     // the choice box of functions
    protected TextField zoomField;     // text field that contains zoom factor

    //=========================================================================
    //  init: Override java.applet.Applet.init -- sets the background color of
    //        the applet and creates the three circles
    //=========================================================================
    public void init () {

	// initialize the applet settings
	this.setBackground( Color.white );
	this.setForeground( Color.black );
	this.setLayout(new BorderLayout(50, 50));
	
	// create the panel for the buttons
	Panel controlPanel = new Panel();
	controlPanel.setLayout(new BorderLayout());
	
	// create pull down list of functions
	pulldownList = new Choice();
	pulldownList.add("x + 1");
	pulldownList.add("x^2 + x + 1");
	pulldownList.add("x^3 + x^2 + x + 1");
        pulldownList.add("sin x");
	
	// create button to graph the function
	Button graphButton = new Button("Graph");
	graphButton.addActionListener(this);
	graphButton.setActionCommand("graph");
 
        // create button to zoom in on the graph
        Button zoomIn = new Button("Zoom In");
        zoomIn.addActionListener(this);
        zoomIn.setActionCommand("zoomIn");

        // create button to zoom out on the graph
        Button zoomOut = new Button("Zoom Out");
        zoomOut.addActionListener(this);
        zoomOut.setActionCommand("zoomOut");

	// create text field for enterring the zoom factor and default it with
	// a '2'
	zoomField = new TextField("2", 2);

	// place zoom features in the zoom panel
	Panel zoomPanel = new Panel();
	zoomPanel.setLayout(new FlowLayout());
	zoomPanel.add(zoomField);
	zoomPanel.add(zoomIn);
        zoomPanel.add(zoomOut);       

	// place components in panel
	controlPanel.add(pulldownList, "West");
	controlPanel.add(graphButton,  "East");
	controlPanel.add(zoomPanel,    "Center");

	// create canvas for graphing
        ga = new Graph(350, 350);

	// add the panel and canvas to the applet
	this.add(controlPanel, "South");
	this.add(ga, "Center");
    }
    
    //=========================================================================
    //  update: Override java.awt.Component.update
    //=========================================================================
    public void update (Graphics g) {
	// update the graph
        ga.paint(ga.getGraphics(), selectedFunction);
    }
    
    //=========================================================================
    // actionPerformed: processes Action events from the user 
    //=========================================================================
    public void actionPerformed (ActionEvent e) {
	String cmd = e.getActionCommand();

	// if the graph button was pressed update the global variable and 
	// repain the canvas
	if (cmd.equals("graph")) {	    
	    selectedFunction = pulldownList.getSelectedIndex();	    
	    repaint();
	} else if (cmd.equals("zoomIn")) {
	    String zf = zoomField.getText();
	    if (zf.length() > 0) { 
		try {
		    Integer nzf = new Integer(zf);
		    zoomFactor  = nzf.intValue();
		} catch (NumberFormatException ex) {
		    zoomField.setText(""+zoomFactor);
		} 
	    }	    

	    ga.zoom(Math.pow(zoomFactor, -1));
	    repaint();
	} else if (cmd.equals("zoomOut")) {
	    String zf = zoomField.getText();
	    if (zf.length() > 0) {
		try {
                    Integer nzf = new Integer(zf);
                    zoomFactor  = nzf.intValue();
		} catch (NumberFormatException ex) {
                    zoomField.setText(""+zoomFactor);
		}
	    }          
	    ga.zoom(zoomFactor);
	    repaint();
	}
    }
}



